@@ -6,7 +6,8 @@ from fastapi import HTTPException, Request, Response
 from freenit.api.router import api
 from freenit.auth import authorize, decode, encode, encrypt
 from freenit.config import getConfig
-from freenit.models.user import User, UserSafe
+from freenit.models.safe import UserSafe
+from freenit.models.user import User
 
 config = getConfig()
 
