@@ -7,24 +7,27 @@ from fastapi import Depends, HTTPException
 from freenit.api.router import route
 from freenit.auth import encrypt
 from freenit.decorators import description
-from freenit.models.user import User, UserOptional, UserSafe
+from freenit.models.safe import UserSafe
+from freenit.models.user import User, UserOptional
 from freenit.permissions import profile_perms, user_perms
 
+tags = ["user"]
 
-@route("/users", tags=["user"])
+
+@route("/users", tags=tags)
 class UserListAPI:
     @staticmethod
     @description("Get users")
     async def get(_: User = Depends(user_perms)) -> List[UserSafe]:
-        return await User.objects.all()
+        return await User.objects.select_all().all()
 
 
-@route("/users/{id}", tags=["user"])
+@route("/users/{id}", tags=tags)
 class UserDetailAPI:
     @staticmethod
     async def get(id: int, _: User = Depends(user_perms)) -> UserSafe:
         try:
-            user = await User.objects.get(pk=id)
+            user = await User.objects.select_all().get(pk=id)
         except ormar.exceptions.NoMatch:
             raise HTTPException(status_code=404, detail="No such user")
         return user
@@ -32,7 +35,7 @@ class UserDetailAPI:
     @staticmethod
     async def delete(id: int, _: User = Depends(user_perms)) -> UserSafe:
         try:
-            user = await User.objects.get(pk=id)
+            user = await User.objects.select_all().get(pk=id)
         except ormar.exceptions.NoMatch:
             raise HTTPException(status_code=404, detail="No such user")
         await user.delete()
@@ -42,16 +45,18 @@ class UserDetailAPI:
 @route("/profile", tags=["profile"])
 class ProfileDetailAPI:
     @staticmethod
-    @description("Get my user")
+    @description("Get my profile")
     async def get(user: User = Depends(profile_perms)) -> UserSafe:
+        await user.load_all()
         return user
 
     @staticmethod
-    @description("Edit my user")
+    @description("Edit my profile")
     async def patch(
         data: UserOptional, user: User = Depends(profile_perms)
     ) -> UserSafe:
         if data.password:
             data.password = encrypt(data.password)
         await user.patch(data)
+        await user.load_all()
         return user
