@@ -1,5 +1,8 @@
+import ormar
+
 from freenit.auth import verify
 from freenit.config import getConfig
+from freenit.models.role import Role
 
 from ..metaclass import AllOptional
 from .base import OrmarBaseModel, OrmarUserMixin
@@ -11,6 +14,8 @@ class User(OrmarBaseModel, OrmarUserMixin):
     class Meta(config.meta):
         tablename = "users"
 
+    roles = ormar.ManyToMany(Role, unique=True)
+
     def check(self, password: str) -> bool:
         return verify(password, self.password)
 
