@@ -1,5 +1,5 @@
 from freenit.auth import permissions
 
-group_perms = permissions()
+role_perms = permissions()
 profile_perms = permissions()
 user_perms = permissions()
