@@ -2,6 +2,7 @@ import factory
 from passlib.hash import pbkdf2_sha256
 
 from freenit.config import getConfig
+from freenit.models.role import Role as RoleModel
 
 config = getConfig()
 auth = config.get_user()
@@ -18,3 +19,10 @@ class User(factory.Factory):
 
 class InactiveUser(User):
     active = False
+
+
+class Role(factory.Factory):
+    class Meta:
+        model = RoleModel
+
+    name = factory.Faker("pystr")
