@@ -1,17 +1,17 @@
 import pytest
 
 from freenit.config import getConfig
+from freenit.models.user import User
 
 from . import factories
 
 config = getConfig()
-auth = config.get_user()
 
 
 class TestUser:
     @pytest.mark.asyncio
     async def test_get_profile(self, client):
-        user = factories.User()
+        user: User = factories.User()
         await user.save()
         client.login(user=user)
         response = client.get("/profile")
@@ -19,7 +19,7 @@ class TestUser:
 
     @pytest.mark.asyncio
     async def test_patch_profile(self, client):
-        admin = factories.User()
+        admin: User = factories.User()
         await admin.save()
         client.login(user=admin)
         data = {
@@ -32,7 +32,7 @@ class TestUser:
 
     @pytest.mark.asyncio
     async def test_get_user_list(self, client):
-        admin = factories.User()
+        admin: User = factories.User()
         await admin.save()
         client.login(user=admin)
         response = client.get(f"/users")
@@ -40,7 +40,7 @@ class TestUser:
 
     @pytest.mark.asyncio
     async def test_get_user_by_id(self, client):
-        admin = factories.User()
+        admin: User = factories.User()
         await admin.save()
         client.login(user=admin)
         response = client.get(f"/users/{admin.id}")
@@ -48,10 +48,10 @@ class TestUser:
 
     @pytest.mark.asyncio
     async def test_delete_user(self, client):
-        admin = factories.User()
+        admin: User = factories.User()
         await admin.save()
         client.login(user=admin)
-        user = factories.User()
+        user: User = factories.User()
         await user.save()
         response = client.delete(f"/users/{user.id}")
         assert response.status_code == 200
